const path = require("path");

module.exports = grunt => {
    grunt.initConfig({
        pkg: grunt.file.readJSON("package.json"),
        clean: {
            default: ["dist/"],
        },
        copy: {
            css: {
                files: [{expand: true, cwd: "src/main/", src: "**/*.css", dest: "dist/", flatten: true}],
            },
        },
        exec: {
            eleventy: "npx @11ty/eleventy",
        },
        focus: {
            dev: {
                include: ["css", "js", "json", "md", "njk"],
            },
        },
        replace: {
            dev: {
                src: ["./dist/**/*.html", "./dist/**/*.js"],
                replacements: [
                    {
                        from: "%%VERSION_NUMBER%%",
                        to: "<%= pkg.version %>+" + new Date().toISOString().slice(0, 19).replace(/[-:T]/g, "")
                    }
                ],
                overwrite: true
            },
            deploy: {
                src: ["./dist/**/*.html", "./dist/**/*.js"],
                replacements: [
                    {
                        from: "%%VERSION_NUMBER%%",
                        to: "<%= pkg.version %>"
                    }
                ],
                overwrite: true
            },
        },
        watch: {
            css: {
                files: ["src/main/**/*.css"],
                tasks: ["copy:css"],
            },
            js: {
                files: ["src/main/**/*.js"],
                tasks: ["webpack:dev", "replace:dev"],
            },
            json: {
                files: ["src/main/**/*.json"],
                tasks: ["exec:eleventy", "replace:dev"],
            },
            md: {
                files: ["src/main/**/*.md"],
                tasks: ["exec:eleventy", "replace:dev"],
            },
            njk: {
                files: ["src/main/**/*.njk"],
                tasks: ["exec:eleventy", "replace:dev"],
            },
        },
        webpack: {
            options: {
                entry: "./src/main/js/main.js",
                module: {
                    rules: [
                        {
                            test: /\.js$/,
                            exclude: /node_modules/,
                        },
                    ],
                },
                resolve: {
                    extensions: [".js"],
                },
                output: {
                    filename: "bundle.js",
                    path: path.resolve(__dirname, "dist/"),
                },
            },
            dev: {
                mode: "development",
                devtool: "inline-source-map",
            },
            deploy: {
                mode: "production",
            },
        },
    });

    grunt.loadNpmTasks("grunt-contrib-clean");
    grunt.loadNpmTasks("grunt-contrib-copy");
    grunt.loadNpmTasks("grunt-contrib-watch");
    grunt.loadNpmTasks("grunt-exec");
    grunt.loadNpmTasks("grunt-focus");
    grunt.loadNpmTasks("grunt-text-replace");
    grunt.loadNpmTasks("grunt-webpack");

    grunt.registerTask("dev", [
        // Pre
        "clean",
        // Generate site
        "copy:css",
        "exec:eleventy",
        // Compile JS
        "webpack:dev",
        "replace:dev",
    ]);
    grunt.registerTask("dev:server", ["dev", "focus:dev"]);
    grunt.registerTask("deploy", [
        // Pre
        "clean",
        // Generate site
        "copy:css",
        "exec:eleventy",
        // Compile JS
        "webpack:deploy",
        "replace:deploy",
    ]);

    grunt.registerTask("default", ["dev"]);
};
